man > lvm-fullreport(8)

LVM(FULLREPORT)                             Red Hat, Inc.                            LVM(FULLREPORT)

NAME
       lvm fullreport — Display full report

SYNOPSIS
       lvm fullreport
           [ option_args ]
           [ position_args ]

DESCRIPTION
       lvm  fullreport  produces  formatted output about PVs, PV segments, VGs, LVs and LV segments.
       The information is all gathered together for each VG (under a per-VG lock) so it  is  consis‐
       tent.  Information  gathered  from separate calls to vgs, pvs, and lvs can be inconsistent if
       information changes between commands.

USAGE
       lvm fullreport
           [ -a|--all ]
           [ -o|--options String ]
           [ -S|--select String ]
           [ -O|--sort String ]
           [    --aligned ]
           [    --binary ]
           [    --configreport log|vg|lv|pv|pvseg|seg ]
           [    --foreign ]
           [    --ignorelockingfailure ]
           [    --logonly ]
           [    --nameprefixes ]
           [    --noheadings ]
           [    --nosuffix ]
           [    --readonly ]
           [    --reportformat basic|json ]
           [    --rows ]
           [    --separator String ]
           [    --shared ]
           [    --unbuffered ]
           [    --units [Number]r|R|h|H|b|B|s|S|k|K|m|M|g|G|t|T|p|P|e|E ]
           [    --unquoted ]
           [ COMMON_OPTIONS ]
           [ VG ... ]

       Common options for lvm:
           [ -d|--debug ]
           [ -h|--help ]
           [ -q|--quiet ]
           [ -t|--test ]
           [ -v|--verbose ]
           [ -y|--yes ]
           [    --commandprofile String ]
           [    --config String ]
           [    --devices PV ]
           [    --devicesfile String ]
           [    --driverloaded y|n ]
           [    --journal String ]
           [    --lockopt String ]
           [    --longhelp ]
           [    --nohints ]
           [    --nolocking ]
           [    --profile String ]
           [    --version ]

OPTIONS


       --aligned
              Use with --separator to align the output columns

       -a|--all


       --binary
              Use binary values "0" or "1" instead of descriptive literal values  for  columns  that
              have  exactly  two  valid values to report (not counting the "unknown" value which de‐
              notes that the value could not be determined).

       --commandprofile String
              The command profile to use for command configuration.  See lvm.conf(5) for more infor‐
              mation about profiles.

       --config String
              Config settings for the command. These override lvm.conf(5) settings.  The String  arg
              uses the same format as lvm.conf(5), or may use section/field syntax.  See lvm.conf(5)
              for more information about config.

       --configreport log|vg|lv|pv|pvseg|seg
              See lvmreport(7).

       -d|--debug ...
              Set  debug  level. Repeat from 1 to 6 times to increase the detail of messages sent to
              the log file and/or syslog (if configured).

       --devices PV
              Restricts the devices that are visible and accessible to  the  command.   Devices  not
              listed will appear to be missing. This option can be repeated, or accepts a comma sep‐
              arated list of devices. This overrides the devices file.

       --devicesfile String
              A  file listing devices that LVM should use.  The file must exist in /etc/lvm/devices/
              and is managed with the lvmdevices(8) command.  This  overrides  the  lvm.conf(5)  de‐
              vices/devicesfile and devices/use_devicesfile settings.

       --driverloaded y|n
              If  set to no, the command will not attempt to use device-mapper.  For testing and de‐
              bugging.

       --foreign
              Report/display foreign VGs that would otherwise be skipped.   See  lvmsystemid(7)  for
              more information about foreign VGs.

       -h|--help
              Display help text.

       --ignorelockingfailure
              Allows  a  command  to continue with read-only metadata operations after locking fail‐
              ures.

       --journal String
              Record information in the systemd journal.  This information is in addition to  infor‐
              mation enabled by the lvm.conf log/journal setting.  command: record information about
              the  command.   output: record the default command output.  debug: record full command
              debugging.

       --lockopt String
              Used to pass options for special cases to lvmlockd.  See lvmlockd(8) for more informa‐
              tion.

       --logonly
              Suppress command report and display only log report.

       --longhelp
              Display long help text.

       --nameprefixes
              Add an "LVM2_" prefix plus the field name to the output. Useful with  --noheadings  to
              produce a list of field=value pairs that can be used to set environment variables (for
              example, in udev rules).

       --noheadings
              Suppress the headings line that is normally the first line of output.  Useful if grep‐
              ping the output.

       --nohints
              Do  not  use the hints file to locate devices for PVs. A command may read more devices
              to find PVs when hints are not used. The command will still perform standard hint file
              invalidation where appropriate.

       --nolocking
              Disable locking. Use with caution, concurrent commands may produce incorrect  results.


       --nosuffix
              Suppress  the  suffix on output sizes. Use with --units (except h and H) if processing
              the output.

       -o|--options String
              Comma-separated, ordered list of fields to display in columns.  String arg syntax  is:
              [+|-|#]Field1[,Field2  ...]   The prefix + will append the specified fields to the de‐
              fault fields, - will remove the specified fields from the default fields, and  #  will
              compact specified fields (removing them when empty for all rows.)  Use -o help to view
              the list of all available fields.  Use separate lists of fields to add, remove or com‐
              pact  by  repeating the -o option: -o+field1,field2 -o-field3,field4 -o#field5.  These
              lists are evaluated from left to right.  Use field name lv_all to view all LV  fields,
              vg_all  all  VG fields, pv_all all PV fields, pvseg_all all PV segment fields, seg_all
              all LV segment fields, and pvseg_all all PV segment columns.  See the lvm.conf(5)  re‐
              port section for more config options.  See lvmreport(7) for more information about re‐
              porting.

       --profile String
              An alias for --commandprofile or --metadataprofile, depending on the command.

       -q|--quiet ...
              Suppress output and log messages. Overrides --debug and --verbose.  Repeat once to al‐
              so suppress any prompts with answer 'no'.

       --readonly
              Run  the  command in a special read-only mode which will read on-disk metadata without
              needing to take any locks. This can be used to peek inside metadata used by a  virtual
              machine  image while the virtual machine is running. No attempt will be made to commu‐
              nicate with the device-mapper kernel driver,  so  this  option  is  unable  to  report
              whether or not LVs are actually in use.

       --reportformat basic|json
              Overrides  current  output  format  for  reports  which is defined globally by the re‐
              port/output_format setting in lvm.conf(5).  basic is the original format with  columns
              and  rows.  If there is more than one report per command, each report is prefixed with
              the report name for identification. json produces report output in  JSON  format.  See
              lvmreport(7) for more information.

       --rows
              Output columns as rows.

       -S|--select String
              Select objects for processing and reporting based on specified criteria.  The criteria
              syntax  is  described  by --select help and lvmreport(7).  For reporting commands, one
              row is displayed for each object matching the criteria.  See --options help for selec‐
              table object fields.  Rows can be displayed with an additional  "selected"  field  (-o
              selected) showing 1 if the row matches the selection and 0 otherwise.  For non-report‐
              ing  commands  which  process  LVM  entities, the selection is used to choose items to
              process.

       --separator String
              String to use to separate each column. Useful if grepping the output.

       --shared
              Report/display shared VGs that would otherwise be skipped when lvmlockd is  not  being
              used on the host.  See lvmlockd(8) for more information about shared VGs.

       -O|--sort String
              Comma-separated  ordered  list  of columns to sort by. Replaces the default selection.
              Precede any column with - for a reverse sort on that column.

       -t|--test
              Run in test mode. Commands will not update metadata.  This is implemented by disabling
              all metadata writing but nevertheless returning success to the calling function.  This
              may lead to unusual error messages in multi-stage operations if a tool relies on read‐
              ing back metadata it believes has changed but hasn't.

       --unbuffered
              Produce output immediately without sorting or aligning the columns properly.

       --units [Number]r|R|h|H|b|B|s|S|k|K|m|M|g|G|t|T|p|P|e|E
              All  sizes  are  output  in these units: human-(r)eadable with '<' rounding indicator,
              (h)uman-readable, (b)ytes, (s)ectors, (k)ilobytes,  (m)egabytes,  (g)igabytes,  (t)er‐
              abytes,  (p)etabytes,  (e)xabytes.  Capitalise to use multiples of 1000 (S.I.) instead
              of 1024.  Custom units can be specified, e.g. --units 3M.

       --unquoted
              When used with --nameprefixes, output values in the field=value pairs are not  quoted.


       -v|--verbose ...
              Set verbose level. Repeat from 1 to 4 times to increase the detail of messages sent to
              stdout and stderr.

       --version
              Display version information.

       -y|--yes
              Do  not  prompt  for  confirmation interactively but always assume the answer yes. Use
              with extreme caution.  (For automatic no, see -qq.)

VARIABLES
       VG     Volume Group name.  See lvm(8) for valid names.

       String See the option description for information about the string content.

       Size[UNIT]
              Size is an input number that accepts an optional unit.  Input units are always treated
              as base two values, regardless of capitalization, e.g. 'k' and 'K' both refer to 1024.
              The default input unit is specified by letter, followed  by  |UNIT.   UNIT  represents
              other possible input units: b|B is bytes, s|S is sectors of 512 bytes, k|K is KiB, m|M
              is  MiB, g|G is GiB, t|T is TiB, p|P is PiB, e|E is EiB.  (This should not be confused
              with the output control --units, where capital letters mean multiple of 1000.)

ENVIRONMENT VARIABLES
       See lvm(8) for information about environment variables used by lvm.  For example, LVM_VG_NAME
       can generally be substituted for a required VG parameter.

SEE ALSO
       lvm(8), lvm.conf(5), lvmconfig(8), lvmdevices(8),

       pvchange(8), pvck(8), pvcreate(8), pvdisplay(8), pvmove(8), pvremove(8), pvresize(8), pvs(8),
       pvscan(8),

       vgcfgbackup(8), vgcfgrestore(8), vgchange(8), vgck(8), vgcreate(8), vgconvert(8),
       vgdisplay(8), vgexport(8), vgextend(8), vgimport(8), vgimportclone(8), vgimportdevices(8),
       vgmerge(8), vgmknodes(8), vgreduce(8), vgremove(8), vgrename(8), vgs(8), vgscan(8),
       vgsplit(8),

       lvcreate(8), lvchange(8), lvconvert(8), lvdisplay(8), lvextend(8), lvreduce(8), lvremove(8),
       lvrename(8), lvresize(8), lvs(8), lvscan(8),

       lvm-fullreport(8), lvm-lvpoll(8), blkdeactivate(8), lvmdump(8),

       dmeventd(8), lvmpolld(8), lvmlockd(8), lvmlockctl(8), cmirrord(8), lvmdbusd(8), fsadm(8),

       lvmsystemid(7), lvmreport(7), lvmraid(7), lvmthin(7), lvmcache(7)

LVM TOOLS 2.03.16(2) (2022-05-18)                 8                                  LVM(FULLREPORT)
lvm-fullreport(8)
NAME SYNOPSIS
lvm fullreport
DESCRIPTION USAGE
lvm fullreport
OPTIONS
--aligned -a|--all --binary -d|--debug ... --foreign -h|--help --ignorelockingfailure --logonly --longhelp --nameprefixes --noheadings --nohints --nolocking --nosuffix -o|--options String -q|--quiet ... --readonly --rows -S|--select String --shared -O|--sort String -t|--test --unbuffered --unquoted -v|--verbose ... --version -y|--yes
VARIABLES ENVIRONMENT VARIABLES SEE ALSO

Generated by phpman v4.10.0-16-g1a0e228 · Markdown · JSON · MCP Author: Che Dong Under GNU General Public License
2026-09-21 13:51 @216.73.216.75
CrawledBy Mozilla/5.0 AppleWebKit/537.36 (KHTML, like Gecko; compatible; ClaudeBot/1.0; +claudebot@anthropic.com)
Valid XHTML 1.0 Transitional!Valid CSS!

^_top_^